@@ -1,8 +1,8 @@
 import dataclasses
-from datetime import date, datetime
-from marshmallow import fields
 import dateutil.parser
 from dataclasses_json import dataclass_json
+from datetime import datetime
+from marshmallow import fields
 from sdk import utils
 
 
@@ -19,4 +19,4 @@ class Schema:
     revision_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('revision_id') }})
     version_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('version_id') }})
     workspace_id: str = dataclasses.field(metadata={'dataclasses_json': { 'letter_case': utils.field_name('workspace_id') }})
-    
+    
\ No newline at end of file
